==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/c7/c75a085490ba867c8ee286a5eb8e954f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js */
class __TwigTemplate_b81dff1e73b8f90ab96cbac1a4740c0a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Serbian (Latin)
 */

\$.FE.LANGUAGE['sr'] = {
  translation: {
    // Place holder
    \"Type something\": \"Ukucajte ne\\u0161tp\",

    // Basic formatting
    \"Bold\": \"Podebljan\",
    \"Italic\": \"Isko\\u0161en\",
    \"Underline\": \"Podvu\\u010deno\",
    \"Strikethrough\": \"Precrtan\",

    // Main buttons
    \"Insert\": \"Umetanje\",
    \"Delete\": \"Izbri\\u0161i\",
    \"Cancel\": \"Otkazivanje\",
    \"OK\": \"Ok\",
    \"Back\": \"Nazad\",
    \"Remove\": \"Uklonite\",
    \"More\": \"Vi\\u0161e\",
    \"Update\": \"A\\u017euriranje\",
    \"Style\": \"Stil\",

    // Font
    \"Font Family\": \"Odaberi font\",
    \"Font Size\": \"Veli\\u010dina fontova\",

    // Colors
    \"Colors\": \"Boje\",
    \"Background\": \"Pozadina\",
    \"Text\": \"Tekst\",

    // Paragraphs
    \"Paragraph Format\": \"Format pasusa\",
    \"Normal\": \"Normalno\",
    \"Code\": \"\\u0160ifra\",
    \"Heading 1\": \"Naslov 1\",
    \"Heading 2\": \"Naslov 2\",
    \"Heading 3\": \"Naslov 3\",
    \"Heading 4\": \"Naslov 4\",

    // Style
    \"Paragraph Style\": \"Stil pasusa\",
    \"Inline Style\": \"Umetnutih stilova\",

    // Alignment
    \"Align\": \"Poravnavanje\",
    \"Align Left\": \"Poravnaj levo\",
    \"Align Center\": \"Poravnaj u centru\",
    \"Align Right\": \"Poravnaj desno\",
    \"Align Justify\": \"Obostrano poravnavanje\",
    \"None\": \"Niko nije\",

    // Lists
    \"Ordered List\": \"Ure\\u0111enih lista\",
    \"Unordered List\": \"Neure\\u0111enu lista\",

    // Indent
    \"Decrease Indent\": \"Smanjivanje uvla\\u010denja\",
    \"Increase Indent\": \"Pove\\u0107avanje uvla\\u010denja\",

    // Links
    \"Insert Link\": \"Umetni vezu\",
    \"Open in new tab\": \"Otvori na novoj kartici\",
    \"Open Link\": \"Otvori vezu\",
    \"Edit Link\": \"Ure\\u0111ivanje veze\",
    \"Unlink\": \"Ukloni vezu\",
    \"Choose Link\": \"Odaberite vezu\",

    // Images
    \"Insert Image\": \"Umetanje slike\",
    \"Upload Image\": \"Otpremanje slika\",
    \"By URL\": \"Po URL adresi\",
    \"Browse\": \"Potra\\u017ei\",
    \"Drop image\": \"Baci sliku\",
    \"or click\": \"ili kliknite na dugme\",
    \"Manage Images\": \"Upravljanje slike\",
    \"Loading\": \"U\\u010ditavanje\",
    \"Deleting\": \"Brisanje\",
    \"Tags\": \"Oznake\",
    \"Are you sure? Image will be deleted.\": \"Jesi siguran? Slika \\u0107e biti izbrisana.\",
    \"Replace\": \"Zameni\",
    \"Uploading\": \"Otpremanje\",
    \"Loading image\": \"U\\u010ditavanje slika\",
    \"Display\": \"Prikaz\",
    \"Inline\": \"Pri upisivanju\",
    \"Break Text\": \"Prelom teksta\",
    \"Alternate Text\": \"Alternativni tekst\",
    \"Change Size\": \"Promena veli\\u010dine\",
    \"Width\": \"\\u0160irina\",
    \"Height\": \"Visina\",
    \"Something went wrong. Please try again.\": \"Ne\\u0161to krenulo naopako. Poku\\u0161ajte ponovo.\",

    // Video
    \"Insert Video\": \"Umetanje video\",
    \"Embedded Code\": \"Ugra\\u0111eni k\\u00f4d\",

    // Tables
    \"Insert Table\": \"Umetni tabelu\",
    \"Table Header\": \"Zaglavlje tabele\",
    \"Remove Table\": \"Uklanjanje tabele\",
    \"Table Style\": \"Stil tabele\",
    \"Horizontal Align\": \"Horizontalno poravnavanje\",
    \"Row\": \"Red\",
    \"Insert row above\": \"Umetni red iznad\",
    \"Insert row below\": \"Umetni red ispod\",
    \"Delete row\": \"Izbri\\u0161i red\",
    \"Column\": \"Kolone\",
    \"Insert column before\": \"Umetnite kolonu pre\",
    \"Insert column after\": \"Umetnite kolonu nakon\",
    \"Delete column\": \"Izbri\\u0161i kolone\",
    \"Cell\": \"Mobilni\",
    \"Merge cells\": \"Objedinjavanje \\u0107elija\",
    \"Horizontal split\": \"Horizontalna split\",
    \"Vertical split\": \"Vertikalno razdelite\",
    \"Cell Background\": \"Mobilni pozadina\",
    \"Vertical Align\": \"Vertikalno poravnavanje\",
    \"Top\": \"Top\",
    \"Middle\": \"Srednji\",
    \"Bottom\": \"Dno\",
    \"Align Top\": \"Poravnaj gore\",
    \"Align Middle\": \"Poravnaj po sredini\",
    \"Align Bottom\": \"Poravnaj dole\",
    \"Cell Style\": \"Mobilni stil\",

    // Files
    \"Upload File\": \"Otpremanje datoteke\",
    \"Drop file\": \"Baci datoteku\",

    // Emoticons
    \"Emoticons\": \"Emotikona\",
    \"Grinning face\": \"Nasmejanoj lice\",
    \"Grinning face with smiling eyes\": \"Nasmejanoj lice sa osmehom o\\u010di\",
    \"Face with tears of joy\": \"Suo\\u010davaju sa suzama radosnicama\",
    \"Smiling face with open mouth\": \"Nasmejano lice sa otvorenim ustima\",
    \"Smiling face with open mouth and smiling eyes\": \"Lica sa otvorenim ustima i nasmejani o\\u010di\",
    \"Smiling face with open mouth and cold sweat\": \"Nasmejano lice sa otvorenih usta i hladan znoj\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Nasmejano lice otvorenih usta i \\u010dvrsto zatvorenih o\\u010diju\",
    \"Smiling face with halo\": \"Nasmejano lice sa oreolom\",
    \"Smiling face with horns\": \"Nasmejano lice sa rogovima\",
    \"Winking face\": \"Namigivanje lice\",
    \"Smiling face with smiling eyes\": \"Lica sa osmehom o\\u010di\",
    \"Face savoring delicious food\": \"Lice u\\u045bivaju\\u0436i u ukusnu hranu\",
    \"Relieved face\": \"Laknulo lice\",
    \"Smiling face with heart-shaped eyes\": \"Nasmejano lice sa o\\u010dima u obliku srca\",
    \"Smiling face with sunglasses\": \"Nasmejano lice sa nao\\u010dare\",
    \"Smirking face\": \"Rugaju\\u0436i lice\",
    \"Neutral face\": \"Neutralno lice\",
    \"Expressionless face\": \"Bez izraza lica.\",
    \"Unamused face\": \"Nije zapaljen lice\",
    \"Face with cold sweat\": \"Suo\\u010davaju sa hladnim znojem\",
    \"Pensive face\": \"Nevesela lica\",
    \"Confused face\": \"Zbunjeno lice\",
    \"Confounded face\": \"Dosadnih lice\",
    \"Kissing face\": \"Ljubim lice\",
    \"Face throwing a kiss\": \"Lice baca poljubac\",
    \"Kissing face with smiling eyes\": \"Ljubi lice sa osmehom o\\u010di\",
    \"Kissing face with closed eyes\": \"Ljubi lice sa zatvorenim o\\u010dima\",
    \"Face with stuck out tongue\": \"Lice sa zaglavio jezik\",
    \"Face with stuck out tongue and winking eye\": \"Lice sa zaglavljen jezik i namigivanje\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Lice sa zaglavljen jezik i cvrsto zatvorene o\\u010di\",
    \"Disappointed face\": \"Razo\\u010darani lice\",
    \"Worried face\": \"Zabrinuto lice\",
    \"Angry face\": \"Ljut lice\",
    \"Pouting face\": \"Zlovoljan lice\",
    \"Crying face\": \"Plakanje lice\",
    \"Persevering face\": \"Istrajnog lice\",
    \"Face with look of triumph\": \"Suo\\u010davaju sa izgledom trijumfa\",
    \"Disappointed but relieved face\": \"Razo\\u010daran ali laknulo lice\",
    \"Frowning face with open mouth\": \"Namršten lice sa otvorenim ustima\",
    \"Anguished face\": \"Enih lica\",
    \"Fearful face\": \"Strahu lice\",
    \"Weary face\": \"Umorna lica\",
    \"Sleepy face\": \"Spava mi se lice\",
    \"Tired face\": \"Umorna lica\",
    \"Grimacing face\": \"Klupi lice\",
    \"Loudly crying face\": \"Glasno plakanje lice\",
    \"Face with open mouth\": \"Suo\\u010davaju sa otvorenim ustima\",
    \"Hushed face\": \"Tihim lice\",
    \"Face with open mouth and cold sweat\": \"Suo\\u010davaju sa otvorenih usta i hladan znoj\",
    \"Face screaming in fear\": \"Lice vrisak u strahu\",
    \"Astonished face\": \"Zadivljeni lice\",
    \"Flushed face\": \"Uplakanu lice\",
    \"Sleeping face\": \"Pospanog lica\",
    \"Dizzy face\": \"Lice mi se vrti\",
    \"Face without mouth\": \"Lice bez jezika\",
    \"Face with medical mask\": \"Suo\\u010davaju sa medicinskim masku\",

    // Line breaker
    \"Break\": \"Prelom\",

    // Math
    \"Subscript\": \"Indeksni tekst\",
    \"Superscript\": \"Eksponentni tekst\",

    // Full screen
    \"Fullscreen\": \"Puni ekran\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Umetni horizontalnu liniju\",

    // Clear formatting
    \"Clear Formatting\": \"Brisanje oblikovanja\",

    // Undo, redo
    \"Undo\": \"Opozovi radnju\",
    \"Redo\": \"Ponavljanje\",

    // Select all
    \"Select All\": \"Izaberi sve\",

    // Code view
    \"Code View\": \"Prikaz koda\",

    // Quote
    \"Quote\": \"Ponude\",
    \"Increase\": \"Pove\\u0107anje\",
    \"Decrease\": \"Smanjivanje\",

    // Quick Insert
    \"Quick Insert\": \"Brzo umetanje\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js");
    }
}

==> production-demo-20260214_152721.tar.gz: var/www/html/production-demo/var/tmp/twig/c7/c75a085490ba867c8ee286a5eb8e954f.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js */
class __TwigTemplate_b81dff1e73b8f90ab96cbac1a4740c0a extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "/*!
 * froala_editor v2.4.2 (https://www.froala.com/wysiwyg-editor)
 * License https://froala.com/wysiwyg-editor/terms/
 * Copyright 2014-2017 Froala Labs
 */

/**
 * Serbian (Latin)
 */

\$.FE.LANGUAGE['sr'] = {
  translation: {
    // Place holder
    \"Type something\": \"Ukucajte ne\\u0161tp\",

    // Basic formatting
    \"Bold\": \"Podebljan\",
    \"Italic\": \"Isko\\u0161en\",
    \"Underline\": \"Podvu\\u010deno\",
    \"Strikethrough\": \"Precrtan\",

    // Main buttons
    \"Insert\": \"Umetanje\",
    \"Delete\": \"Izbri\\u0161i\",
    \"Cancel\": \"Otkazivanje\",
    \"OK\": \"Ok\",
    \"Back\": \"Nazad\",
    \"Remove\": \"Uklonite\",
    \"More\": \"Vi\\u0161e\",
    \"Update\": \"A\\u017euriranje\",
    \"Style\": \"Stil\",

    // Font
    \"Font Family\": \"Odaberi font\",
    \"Font Size\": \"Veli\\u010dina fontova\",

    // Colors
    \"Colors\": \"Boje\",
    \"Background\": \"Pozadina\",
    \"Text\": \"Tekst\",

    // Paragraphs
    \"Paragraph Format\": \"Format pasusa\",
    \"Normal\": \"Normalno\",
    \"Code\": \"\\u0160ifra\",
    \"Heading 1\": \"Naslov 1\",
    \"Heading 2\": \"Naslov 2\",
    \"Heading 3\": \"Naslov 3\",
    \"Heading 4\": \"Naslov 4\",

    // Style
    \"Paragraph Style\": \"Stil pasusa\",
    \"Inline Style\": \"Umetnutih stilova\",

    // Alignment
    \"Align\": \"Poravnavanje\",
    \"Align Left\": \"Poravnaj levo\",
    \"Align Center\": \"Poravnaj u centru\",
    \"Align Right\": \"Poravnaj desno\",
    \"Align Justify\": \"Obostrano poravnavanje\",
    \"None\": \"Niko nije\",

    // Lists
    \"Ordered List\": \"Ure\\u0111enih lista\",
    \"Unordered List\": \"Neure\\u0111enu lista\",

    // Indent
    \"Decrease Indent\": \"Smanjivanje uvla\\u010denja\",
    \"Increase Indent\": \"Pove\\u0107avanje uvla\\u010denja\",

    // Links
    \"Insert Link\": \"Umetni vezu\",
    \"Open in new tab\": \"Otvori na novoj kartici\",
    \"Open Link\": \"Otvori vezu\",
    \"Edit Link\": \"Ure\\u0111ivanje veze\",
    \"Unlink\": \"Ukloni vezu\",
    \"Choose Link\": \"Odaberite vezu\",

    // Images
    \"Insert Image\": \"Umetanje slike\",
    \"Upload Image\": \"Otpremanje slika\",
    \"By URL\": \"Po URL adresi\",
    \"Browse\": \"Potra\\u017ei\",
    \"Drop image\": \"Baci sliku\",
    \"or click\": \"ili kliknite na dugme\",
    \"Manage Images\": \"Upravljanje slike\",
    \"Loading\": \"U\\u010ditavanje\",
    \"Deleting\": \"Brisanje\",
    \"Tags\": \"Oznake\",
    \"Are you sure? Image will be deleted.\": \"Jesi siguran? Slika \\u0107e biti izbrisana.\",
    \"Replace\": \"Zameni\",
    \"Uploading\": \"Otpremanje\",
    \"Loading image\": \"U\\u010ditavanje slika\",
    \"Display\": \"Prikaz\",
    \"Inline\": \"Pri upisivanju\",
    \"Break Text\": \"Prelom teksta\",
    \"Alternate Text\": \"Alternativni tekst\",
    \"Change Size\": \"Promena veli\\u010dine\",
    \"Width\": \"\\u0160irina\",
    \"Height\": \"Visina\",
    \"Something went wrong. Please try again.\": \"Ne\\u0161to krenulo naopako. Poku\\u0161ajte ponovo.\",

    // Video
    \"Insert Video\": \"Umetanje video\",
    \"Embedded Code\": \"Ugra\\u0111eni k\\u00f4d\",

    // Tables
    \"Insert Table\": \"Umetni tabelu\",
    \"Table Header\": \"Zaglavlje tabele\",
    \"Remove Table\": \"Uklanjanje tabele\",
    \"Table Style\": \"Stil tabele\",
    \"Horizontal Align\": \"Horizontalno poravnavanje\",
    \"Row\": \"Red\",
    \"Insert row above\": \"Umetni red iznad\",
    \"Insert row below\": \"Umetni red ispod\",
    \"Delete row\": \"Izbri\\u0161i red\",
    \"Column\": \"Kolone\",
    \"Insert column before\": \"Umetnite kolonu pre\",
    \"Insert column after\": \"Umetnite kolonu nakon\",
    \"Delete column\": \"Izbri\\u0161i kolone\",
    \"Cell\": \"Mobilni\",
    \"Merge cells\": \"Objedinjavanje \\u0107elija\",
    \"Horizontal split\": \"Horizontalna split\",
    \"Vertical split\": \"Vertikalno razdelite\",
    \"Cell Background\": \"Mobilni pozadina\",
    \"Vertical Align\": \"Vertikalno poravnavanje\",
    \"Top\": \"Top\",
    \"Middle\": \"Srednji\",
    \"Bottom\": \"Dno\",
    \"Align Top\": \"Poravnaj gore\",
    \"Align Middle\": \"Poravnaj po sredini\",
    \"Align Bottom\": \"Poravnaj dole\",
    \"Cell Style\": \"Mobilni stil\",

    // Files
    \"Upload File\": \"Otpremanje datoteke\",
    \"Drop file\": \"Baci datoteku\",

    // Emoticons
    \"Emoticons\": \"Emotikona\",
    \"Grinning face\": \"Nasmejanoj lice\",
    \"Grinning face with smiling eyes\": \"Nasmejanoj lice sa osmehom o\\u010di\",
    \"Face with tears of joy\": \"Suo\\u010davaju sa suzama radosnicama\",
    \"Smiling face with open mouth\": \"Nasmejano lice sa otvorenim ustima\",
    \"Smiling face with open mouth and smiling eyes\": \"Lica sa otvorenim ustima i nasmejani o\\u010di\",
    \"Smiling face with open mouth and cold sweat\": \"Nasmejano lice sa otvorenih usta i hladan znoj\",
    \"Smiling face with open mouth and tightly-closed eyes\": \"Nasmejano lice otvorenih usta i \\u010dvrsto zatvorenih o\\u010diju\",
    \"Smiling face with halo\": \"Nasmejano lice sa oreolom\",
    \"Smiling face with horns\": \"Nasmejano lice sa rogovima\",
    \"Winking face\": \"Namigivanje lice\",
    \"Smiling face with smiling eyes\": \"Lica sa osmehom o\\u010di\",
    \"Face savoring delicious food\": \"Lice u\\u045bivaju\\u0436i u ukusnu hranu\",
    \"Relieved face\": \"Laknulo lice\",
    \"Smiling face with heart-shaped eyes\": \"Nasmejano lice sa o\\u010dima u obliku srca\",
    \"Smiling face with sunglasses\": \"Nasmejano lice sa nao\\u010dare\",
    \"Smirking face\": \"Rugaju\\u0436i lice\",
    \"Neutral face\": \"Neutralno lice\",
    \"Expressionless face\": \"Bez izraza lica.\",
    \"Unamused face\": \"Nije zapaljen lice\",
    \"Face with cold sweat\": \"Suo\\u010davaju sa hladnim znojem\",
    \"Pensive face\": \"Nevesela lica\",
    \"Confused face\": \"Zbunjeno lice\",
    \"Confounded face\": \"Dosadnih lice\",
    \"Kissing face\": \"Ljubim lice\",
    \"Face throwing a kiss\": \"Lice baca poljubac\",
    \"Kissing face with smiling eyes\": \"Ljubi lice sa osmehom o\\u010di\",
    \"Kissing face with closed eyes\": \"Ljubi lice sa zatvorenim o\\u010dima\",
    \"Face with stuck out tongue\": \"Lice sa zaglavio jezik\",
    \"Face with stuck out tongue and winking eye\": \"Lice sa zaglavljen jezik i namigivanje\",
    \"Face with stuck out tongue and tightly-closed eyes\": \"Lice sa zaglavljen jezik i cvrsto zatvorene o\\u010di\",
    \"Disappointed face\": \"Razo\\u010darani lice\",
    \"Worried face\": \"Zabrinuto lice\",
    \"Angry face\": \"Ljut lice\",
    \"Pouting face\": \"Zlovoljan lice\",
    \"Crying face\": \"Plakanje lice\",
    \"Persevering face\": \"Istrajnog lice\",
    \"Face with look of triumph\": \"Suo\\u010davaju sa izgledom trijumfa\",
    \"Disappointed but relieved face\": \"Razo\\u010daran ali laknulo lice\",
    \"Frowning face with open mouth\": \"Namršten lice sa otvorenim ustima\",
    \"Anguished face\": \"Enih lica\",
    \"Fearful face\": \"Strahu lice\",
    \"Weary face\": \"Umorna lica\",
    \"Sleepy face\": \"Spava mi se lice\",
    \"Tired face\": \"Umorna lica\",
    \"Grimacing face\": \"Klupi lice\",
    \"Loudly crying face\": \"Glasno plakanje lice\",
    \"Face with open mouth\": \"Suo\\u010davaju sa otvorenim ustima\",
    \"Hushed face\": \"Tihim lice\",
    \"Face with open mouth and cold sweat\": \"Suo\\u010davaju sa otvorenih usta i hladan znoj\",
    \"Face screaming in fear\": \"Lice vrisak u strahu\",
    \"Astonished face\": \"Zadivljeni lice\",
    \"Flushed face\": \"Uplakanu lice\",
    \"Sleeping face\": \"Pospanog lica\",
    \"Dizzy face\": \"Lice mi se vrti\",
    \"Face without mouth\": \"Lice bez jezika\",
    \"Face with medical mask\": \"Suo\\u010davaju sa medicinskim masku\",

    // Line breaker
    \"Break\": \"Prelom\",

    // Math
    \"Subscript\": \"Indeksni tekst\",
    \"Superscript\": \"Eksponentni tekst\",

    // Full screen
    \"Fullscreen\": \"Puni ekran\",

    // Horizontal line
    \"Insert Horizontal Line\": \"Umetni horizontalnu liniju\",

    // Clear formatting
    \"Clear Formatting\": \"Brisanje oblikovanja\",

    // Undo, redo
    \"Undo\": \"Opozovi radnju\",
    \"Redo\": \"Ponavljanje\",

    // Select all
    \"Select All\": \"Izaberi sve\",

    // Code view
    \"Code View\": \"Prikaz koda\",

    // Quote
    \"Quote\": \"Ponude\",
    \"Increase\": \"Pove\\u0107anje\",
    \"Decrease\": \"Smanjivanje\",

    // Quick Insert
    \"Quick Insert\": \"Brzo umetanje\"
  },
  direction: \"ltr\"
};
";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js", "/var/www/html/production-demo/app/bundles/CoreBundle/Assets/js/libraries/froala/languages/sr.js");
    }
}
